;;  edivad-suite a simple suite of gimp scripts for simplify my life
;;  Copyright (C) 2008  Davide Giannella <edivad_@users.sourceforge.net>
;;
;;  This program is free software; you can redistribute it and/or modify
;;  it under the terms of the GNU General Public License as published by
;;  the Free Software Foundation; version 2 of the License.
;; 
;;  This program is distributed in the hope that it will be useful,
;;  but WITHOUT ANY WARRANTY; without even the implied warranty of
;;  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;  GNU General Public License for more details.
;;
;;  You should have received a copy of the GNU General Public License along
;;  with this program; if not, write to the Free Software Foundation, Inc.,
;;  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

(define pixel-per-cm 118)
(define PORTRAIT 1)
(define LANDSCAPE 0)

(define PATTERNS '("*.jpg" "*.tiff" "*.tif" "*.xcf")) ;; beware editing this array. You will also have to modify the build-pattern function
(define RAW_PATTERNS '("*.cr2"))

;;
; parse the file path and return it without extension
;
; @param filename String the file path 
; @return the file path without the extension
(define (parse-name filename)
  (let*
      (
       (fparts (strbreakup filename "."))
       (y 0)
       (out "")
       (lngt (- (length fparts) 1))
       )
    (while (< y lngt)
           (set! out (string-append out (nth y fparts)))
           (set! y (+ y 1))
           (if (< y lngt)
               (set! out (string-append out "."))
               )
           )
    (car (cons out '()))
    )
)

;;
; retrieve the dimensions of the provided image and return the right width+height for the web
;
; @param img IMAGE the loaded image
; @param long-side the long side required for scaling. If 0 the actual image dimension is returned
; @return a list with at the firt item the widht and the last the height (width, heigh)
(define (get-dimension img long-side)
  (let*
      (
       (w (car (gimp-image-width img)))
       (h (car (gimp-image-height img)))
       (w2 w)
       (h2 h)
       )
    
    (print w2)
    (print h2)
    (print long-side)
    (if (not (= long-side 0))
        (begin
          (cond
           ((> w h)
            (set! w2 long-side)
            (set! h2 (/ (* h long-side) w))
            )
           ((< w h)
            (set! w2 (/ (* w long-side) h))
            (set! h2 long-side)
            )
           )
          )
    )
    (list w2 h2)
  )
)

;;;
;; retrieve the file-glob pattern in the PATTERN list by the index specified
;; 
;; @param index SF-VALUE the user selection
;; @return the file-glob pattern
(define (get-pattern index)
  (let*
      (
       (ptr "none")
      )
     (cond
        ((= index 0) (set! ptr "*.[jJ][pP][gG]"))
        ((= index 1) (set! ptr "*.[tT][iI][fF][fF]"))
        ((= index 2) (set! ptr "*.[tT][iI][fF]"))
        ((= index 3) (set! ptr "*.[xX][cC][fF]"))
        )
     (list ptr)
  )
)

;;;;
;; retrieve the pattern for file-glob corresponding to the provided position for the RAW_PATTERN list
;; 
;; @param index SF-VALUE the index desired
;; @return the file-glob pattern
(define (get-rawpattern index)
  (let*
      (
       (ptr "none")
       )
    (cond
     ((= index 0) (set! ptr "*.[cC][rR]2"))
     )
    (list ptr)
    )
)

;;;;
;; return the pattern for file-glob by the provided path and the index of the selected item
;; 
;; @param path SF-DIRECTORY a valid path
;; @param pattern STRING the pattern
;; @return the pattern for file-glob
(define (build-pattern path pattern)
   (let*
       (
        (splittedBackSlash (strbreakup path "\\"))
        (splittedSlash (strbreakup path "/"))
        (ptr2 "")
        (e "")
       )
     ;;fixing for "\"
     (if (> (length splittedBackSlash) 1)
         (while (not (null? splittedBackSlash))
                (set! e (car splittedBackSlash))
                (if (> (string-length e) 0)
                     (set! ptr2 (string-append ptr2 e "\\"))
                )
                (set! splittedBackSlash (cdr splittedBackSlash))
         )
     )
     
     ;;fixing for "/"
     (if (> (length splittedSlash) 1)
         (while (not (null? splittedSlash))
                (set! e (car splittedSlash))
                (if (> (string-length e) 0)
                     (set! ptr2 (string-append ptr2 e "/"))
                )
                (set! splittedSlash (cdr splittedSlash))
         )
     )
     
     (set! ptr2 (string-append ptr2 pattern))
     (list ptr2)
   )
)

;;
; scale and move the image layer in order to impaginate it
;
; @param INT32 layer the active layer id
; @param INT32 pixel-per-cm the amount of pixels per cm.
(define (scale-and-move-layer layer pixel-per-cm)
  (let*
      ( 
       (PORTRAIT 1)
       (LANDSCAPE 0)
       (long-side-landscape (* pixel-per-cm 23))
       (long-side-portrait (* pixel-per-cm 18))
       (orientation (get-drawable-orientation layer))
       (dimensions (get-drw-dimension layer long-side-landscape long-side-portrait))
       (width-scaled (car dimensions))
       (height-scaled (cadr dimensions))
      )

    (gimp-layer-scale layer width-scaled height-scaled FALSE) ;scale the layer to fit required dimensions

    ;move the layer
    (cond
     ((= orientation LANDSCAPE)
      (gimp-layer-set-offsets layer (* pixel-per-cm 6) pixel-per-cm)
     )
     ((= orientation PORTRAIT)
      (gimp-layer-set-offsets layer (* pixel-per-cm 17) pixel-per-cm)
     )
    )
  )
)

;;
; return the drawable orientation landscape or portrait
;
; @param SF-DRAWABLE drw the drawable
; @return INT32 PORTRAIT (1) or LANDSCAPE (0)
(define (get-drawable-orientation drw)
  (let*
    (
     (LANDSCAPE 0)
     (PORTRAIT 1)
     (orientation LANDSCAPE)
     (width (car (gimp-drawable-width drw)))
     (height (car (gimp-drawable-height drw)))
    )
    (if (< width height)
        (set! orientation PORTRAIT)
    )
    (car (cons orientation '()))
  )
)

;;
; retrieve the dimensions of the provided drawable and return the scaled width+height
;
; @param img SF-DRAWABLE the drawable
; @param long-side-lanscape INT32 the long side for the landscape format
; @param long-side-portrait INT32 the long side for the portrait format
; @return a list with at the firt item the widht and the last the height (width, heigh)
(define (get-drw-dimension img long-side-landscape long-side-portrait)
  (let*
   (
    (w (car (gimp-drawable-width img)))
    (h (car (gimp-drawable-height img)))
    (w2 0)
    (h2 0)
   )
   (cond 
    ((> w h)
     (set! w2 long-side-landscape)
     (set! h2 (/ (* h long-side-landscape) w))
    )
    ((< w h)
     (set! w2 (/ (* w long-side-portrait) h))
     (set! h2 long-side-portrait)
    )
   )
   (list w2 h2)
  )
)
