;;  edivad-suite a simple suite of gimp scripts for simplify my life
;;  Copyright (C) 2008  Davide Giannella <edivad_@users.sourceforge.net>
;;
;;  This program is free software; you can redistribute it and/or modify
;;  it under the terms of the GNU General Public License as published by
;;  the Free Software Foundation; version 2 of the License.
;; 
;;  This program is distributed in the hope that it will be useful,
;;  but WITHOUT ANY WARRANTY; without even the implied warranty of
;;  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;  GNU General Public License for more details.
;;
;;  You should have received a copy of the GNU General Public License along
;;  with this program; if not, write to the Free Software Foundation, Inc.,
;;  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

;;
; add the caption to the image
;
; @param SF-IMAGE img the image
; @param INT32 orientation the orientation of the pic. LANDSCAPE (0) PORTRAIT (1)
(define (add-caption img orientation)
  (let*
    (
     (text-landscape "Lorem ipsum dolor sit amet, consectetuer adipiscing elit.\nMaecenas viverra urna a magna pulvinar fringilla.\nNulla ornare ultricies leo. Sed at tortor. Nulla aliquet, mi quis ullamcorper faucibus,\nsapien erat malesuada elit, eget sollicitudin nisi urna sed dui. Curabitur vulputate nibh ut magna.")
     (text-portrait "Lorem ipsum dolor sit amet, consectetuer adipiscing elit.\nMaecenas viverra urna a magna pulvinar fringilla.Nulla \nornare ultricies leo. Sed at tortor. Nulla aliquet, mi quis \nullamcorper faucibus, sapien erat malesuada elit, eget \nsollicitudin nisi urna sed dui. Curabitur vulputate nibh \nut magna.")
     (x-landscape (* pixel-per-cm 2))
     (y-landscape (* pixel-per-cm 17))
     (x-portrait (* pixel-per-cm 2))
     (y-portrait (* pixel-per-cm 16))
     (font-size 50)
     (font-face "Arial")
     (text-color '(150 146 146))
     (original-foreground (car (gimp-context-get-foreground)))
     (text-float 0)
    )

    (gimp-context-set-foreground text-color)

    (cond
     ((= orientation LANDSCAPE)
      (set! text-float (car (gimp-text-fontname img
                                                -1
                                                x-landscape
                                                y-landscape
                                                text-landscape
                                                -1
                                                TRUE
                                                font-size
                                                1
                                                font-face)))
     )
     ((= orientation PORTRAIT)
      (set! text-float (car (gimp-text-fontname img
                                                -1
                                                x-portrait
                                                y-portrait
                                                text-portrait
                                                -1
                                                TRUE
                                                font-size
                                                1
                                                font-face)))
     )
    )

    (gimp-context-set-foreground original-foreground)
  )
)

;;
; take the provided image and create a porfolio layout by that.
; this means 20x30cm page at 300dpi with 1cm margins, space for binding,
; and a sample text for caption.
; 
; @param SF-IMAGE img the active image
; @param SF-DRAWABLE drw the active drawable
; @return INT32 the id of the generated image
(define (portfolio img drw)
  (let*
      (
       (fname (parse-name (car (gimp-image-get-filename img))))
       (width-paged 3543)
       (height-paged 2363)
       (dpi 300)
       (img-dup (car (gimp-image-duplicate img))) ; duplicate the actual image (no editing on exsiting file)
       (drw-flatten (car (gimp-image-flatten img-dup))) ; flatten the new image (only one layer)
       (img-flatten (car (gimp-drawable-get-image drw-flatten)))
       (img-paged 0)
       (layer-background 0)
       (display-paged 0)
       (layer-image 0)
       )
    (print pixel-per-cm)
    (print PORTRAIT)
    (print LANDSCAPE)
    (gimp-image-set-resolution img-flatten dpi dpi) ;ensure to have 300dpi res
    
    (set! img-paged (car (gimp-image-new width-paged height-paged RGB)))
    (set! layer-background (car (gimp-layer-new img-paged width-paged height-paged RGB-IMAGE "Background" 100 NORMAL-MODE)))
    (gimp-image-set-resolution img-paged dpi dpi)
    (gimp-image-add-layer img-paged layer-background -1)
    (gimp-edit-fill layer-background 2)
    (set! display-paged (gimp-display-new img-paged))

    (set! layer-image (car (gimp-layer-new-from-drawable drw-flatten img-paged)))
    (gimp-image-add-layer img-paged layer-image 0)

    (gimp-image-delete img-flatten) ;close the duplicated flattened image

    (scale-and-move-layer layer-image pixel-per-cm)

    (add-caption img-paged (get-drawable-orientation layer-image))

    ;adding guides for margin
    (gimp-image-add-vguide img-paged (* pixel-per-cm 2))
    (gimp-image-add-vguide img-paged (* pixel-per-cm 29))
    (gimp-image-add-hguide img-paged (* pixel-per-cm 1))
    (gimp-image-add-hguide img-paged (* pixel-per-cm 19))

    (gimp-image-set-filename img-paged (string-append (parse-name (car (gimp-image-get-filename img))) "-paged.xcf"))

    (gimp-displays-flush)

    (cons img-paged display-paged)
  )
)

(define (portfolio-dir path)
  (let*
   (
    (pattern (car (build-pattern path "*.[xX][cC][fF]")))
    (filelist (cadr (file-glob pattern 1)))
    (filename 0)
    (img 0)
    (drw 0)
    (img-paged 0)
    (display-paged 0)
    (drw-paged 0)
    (filename-paged 0)
    (ret 0)
   )
   (while (not (null? filelist))
          (set! filename (car filelist))

          (set! img (car (gimp-file-load RUN-NONINTERACTIVE filename filename)))
          (set! drw (car (gimp-image-get-active-drawable img)))

          (set! ret (portfolio img drw)) ;create the paged layout
          (set! img-paged (car ret)) 
          (set! display-paged (cadr ret))
          (set! drw-paged (car (gimp-image-get-active-drawable img-paged)))
          (set! filename-paged (car (gimp-image-get-filename img-paged)))
          (gimp-file-save RUN-NONINTERACTIVE img-paged drw-paged filename-paged filename-paged) ;save the paged image
          
          (gimp-display-delete display-paged) ;close the paged display
          (gimp-image-delete img) ;close the original image

          (set! filelist (cdr filelist))
   )
  )
)

(script-fu-register "portfolio"
                    _"<Image>/Script-Fu/edivad-suite/Portfolio"
                    "Take the active image and impaginate it for portfolio"
                    "Davide Giannella"
                    "(C) 2008 Davide Giannella"
                    "October 2008"
                    ""
                    SF-IMAGE "Image" 0
                    SF-DRAWABLE "Drawable" 0
)

(script-fu-register "portfolio-dir"
                    _"<Toolbox>/Xtns/Script-Fu/edivad-suite/Portfolio Directory"
                    "Take the selected direcoty and process all XCF inside it generating a paged copy"
                    "Davide Giannella"
                    "(C) 2008 Davide Giannella"
                    "May 2008"
                    ""
                    SF-DIRNAME "Directory" ""
)
