;;  edivad-suite a simple suite of gimp scripts for simplify my life
;;  Copyright (C) 2008  Davide Giannella <edivad_@users.sourceforge.net>
;;
;;  This program is free software; you can redistribute it and/or modify
;;  it under the terms of the GNU General Public License as published by
;;  the Free Software Foundation; version 2 of the License.
;; 
;;  This program is distributed in the hope that it will be useful,
;;  but WITHOUT ANY WARRANTY; without even the implied warranty of
;;  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;  GNU General Public License for more details.
;;
;;  You should have received a copy of the GNU General Public License along
;;  with this program; if not, write to the Free Software Foundation, Inc.,
;;  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

;;;;
;; Take the provided camera RAW file and convert it into jpg.
;; 
;; @param path SF-FILENAME the file to process
;; @param web SF-TOGGLE if you want to webify the image or simply generate an 85% jpg full size
;; @param equalize SF-TOGGLE if you want to equalize the image or not. 
(define (raw2jpg-file path web equalize)
  (let*
      (
       (quality 85)
       (long-side 800)
       (fname (string-append (parse-name path) ".jpg"))
       (image (car (file-ufraw-load 1 path path)))
       (draw (car (gimp-image-get-active-layer image)))
       )
    
    ;;sometimes ufraw seems to underexpose the image. Try to fix this behaviour
    (if (= equalize TRUE)
        (gimp-equalize draw FALSE)
        )
    
    (if (= web TRUE)
        (webify image draw quality long-side)
        (file-jpeg-save 1 image draw fname fname (/ quality 100) 0 0 0 " " 0 1 0 1)
        )
    
    (gimp-image-delete image)
  )
)

(define (raw2jpg-dir dir pattern web equalize)
  (let*
      (
       (ptr (car (build-pattern dir (car (get-rawpattern pattern)))))
       (filelist 0)
       (filename 0)
       )
    (set! filelist (cadr (file-glob ptr 1)))
    (while (not (null? filelist))
           (set! filename (car filelist))
           (raw2jpg-file filename web equalize)
           (set! filelist (cdr filelist))
           )
    )
)

(script-fu-register "raw2jpg-file"
                    _"<Toolbox>/Xtns/Script-Fu/edivad-suite/Raw 2 Jpg/Single File"
                    "Take the selected raw image and convert it into jpg"
                    "Davide Giannella"
                    "(C) Davide Giannella"
                    "October 2008"
                    ""
                    SF-FILENAME "File Path" ""
                    SF-TOGGLE "Webify! (jpg 85% compression, 800px long side)" TRUE
                    SF-TOGGLE "Equalize" TRUE
                    )

(script-fu-register "raw2jpg-dir"
                    _"<Toolbox>/Xtns/Script-Fu/edivad-suite/Raw 2 Jpg/Directory"
                    "Take provided directory and convert all raw into jpg"
                    "Davide Giannella"
                    "(C) Davide Giannella"
                    "October 2008"
                    ""
                    SF-DIRNAME "Directory" ""
                    SF-OPTION "Pattern" RAW_PATTERNS
                    SF-TOGGLE "Webify! (jpg 85% compression, 800px long side)" TRUE
                    SF-TOGGLE "Equalize" TRUE
                    )